@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2001-2005 Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
+** Copyright (C) 2001-2008 Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -16,8 +16,6 @@
 ** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 **  
 */
-
-
 #define _GNU_SOURCE
 
 #include <stdio.h>
@@ -37,7 +35,6 @@
 static const char* VANDALE_SERVER = "www.vandale.nl";
 static const char* VANDALE_PORT   = "80";
 
-
 /*
  * http stuff; the HTTP_REQUEST / HTTP_REQUEST_PROXY have _2_
  * %s fields (for the search term)
@@ -391,8 +388,9 @@ vd_filter_http_buffer (Buffer *http_buffer, VDError* ex)
 	
 	static const char* word        = "<span class=\"g1v\">";
 	static const char* notfound    = "Geen resultaat.";
-	static const char* metanav     = "<div class=\"metaNav\">";
-	
+	static const char* metanav     = "class=\"metaNav\">";
+	static const char *href        = "href=";
+
 	assert (http_buffer);
 	assert (ex);
 	
@@ -409,10 +407,17 @@ vd_filter_http_buffer (Buffer *http_buffer, VDError* ex)
 		return;
 	}
 
-	/* cut trailing stuff */
+	/* cut trailing stuff; we try metaNav first, then href, to be
+	*  safe against tiny changes in the webpage...
+	*/
 	pos = buffer_find (http_buffer, metanav, strlen(metanav));
+	if (pos == buffer_end (http_buffer)) 
+		pos = buffer_find (http_buffer, href, strlen(href));
+	
 	if (pos < buffer_end (http_buffer))
 		buffer_erase (http_buffer, pos, buffer_end(http_buffer) - pos);
+	
+
 
 	/* find the last non-blank */
 	for (pos = buffer_end(http_buffer) - 1; pos >= buffer_begin(http_buffer); --pos) {
