@@ -1,5 +1,5 @@
 /*
- ** Copyright (C) 2001-2005 Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
+ ** Copyright (C) 2001-2008 Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
  **  
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -34,6 +34,12 @@
 
 #include "gnuvd.h"
 
+#if HAVE_STRNDUP
+/*OK*/
+#else
+#define strndup(s,n) strdup(s) 
+#endif /*HAVE_STRNDUP*/
+
 #ifndef VERSION
 #define VERSION "?.?"
 #endif /*VERSION*/
@@ -87,7 +93,7 @@ main (int argc, char* argv[])
 			fprintf (stderr, "error: %s\n", 
 				 vd_error_string(vd_ex));
 		else 	
-			fprintf (stderr, "an unknown error occured\n");
+			fprintf (stderr, "an unknown error occurred\n");
 		return 1;
 	}
 
@@ -183,9 +189,8 @@ show_results (Buffer* buffer, int keep_entities)
 	}
 }
 
-
 static void
-help()
+help(void)
 {
 	printf ("gnuvd version " VERSION  ",\n"
 		"(c) 2001-2008 Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>\n\n"
